************************************************************************************************************************
************************************************************************************************************************
**** Project: Kenyan information experiment paper
**** Authors: Solomon Zena Walelign
**** Version: August 7, 2021
**** Purpose: processing the Kenyan KDRDIP baseline dataset 
************************************************************************************************************************
************************************************************************************************************************

//== GLOBAL MACROS WITH RELEVANT DIRECTORIES ===========================================================================
// directories incuding data, processed tables, processed figures and other output
quietly include "`c(pwd)'/env_setup/env.do" 
assert "${data_path}" != "" & "${table_path}" != "" & "${figure_path}" != "" // should be defined

//== READ the KDRDIP baseline data set without household demographics demographics===================================================
use "${data_path}/KDRDIP_supplementary baseline household survey datasets.dta", clear 
save  "${data_path}/processed/KDRDP_baseline_data", replace

//== READ the KDRDIP household demographics baseline dataset============================================================
use "${data_path}/KDRDIP_supplementary baseline household survey datasets - demographics (wide -long fomart).dta", clear 
gen attend_school=. 
replace attend_school=1 if a110==1
replace attend_school=0 if a110==2
gen housewife=1 if a119==3
collapse (count) women_25_60_number=a104 (mean) women_25_60_educ_mean=a109 (mean) women_25_60_age_mean=a104 (count) women_25_60_atte_scho_num=attend_school women_25_60_housewif_num=housewife if (a104>=25 & a104<=60) & a103==2, by(KEY) 

//number of women aged between 25 and 60 for each household
save  "${data_path}/processed/KDRDP_baseline_women_25_60_characterstics.dta", replace

use "${data_path}/KDRDIP_supplementary baseline household survey datasets - demographics (wide -long fomart).dta", clear 
gen adult_female_14_65=0 
replace adult_female_14_65=1 if a104>14 & a104<65 & a103==2

gen adult_male_14_65=0 
replace adult_male_14_65=1 if a104>14 & a104<65 & a103==1

gen child_0_6=0 
replace child_0_6=1 if a104<7

gen child_7_13=0 
replace child_7_13=1 if a104>7 & a104<14

gen elder_65=0 
replace elder_65=1 if a104>64 & a104!=.

collapse (sum) child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65, by(KEY)

save  "${data_path}/processed/KDRDP_baseline_hh_number_by_age.dta", replace

merge 1:1 KEY using "${data_path}/processed/KDRDP_baseline_women_25_60_characterstics.dta"
drop _merge 

//merging the proccesed women characterstics dataset with the main dataset
merge 1:1 KEY using "${data_path}/processed/KDRDP_baseline_data" 
drop _merge 

//generating a variable for information experiment treatment status
gen info_types=1 if !missing(tq1) 
replace info_types=0 if !missing(cq1)
label define info_types 1 "treatment" 0 "control/placebo"
label variable info_types "information experiment treatment status"
tab info_types 

//checking for missing values in the information experiment outcome variables
tab types 
*we would expect about 1264 households to participate in the information experiment if all households have a women aged between 25 and 60 which is about 632 per treatment arm
*this could be due to the fact that households does not have a family member aged between 25 and 60.

tab tq1 
tab tq2
*we have only 405 households in the information treatment group, implying an expected deficiet of about 227 households (i.e., 632-405)
*this could be again due to the fact that households does not have a family member aged between 25 and 60. 

tab  cq1
tab  cq2
*we have only 438 households in the information placebo (control group), implying an expected deficiet of about 194 households (i.e., 632-427)

tab women_25_60_number 
tab women_25_60_number types 
*we have 1803 households with a women aged between 25 and 60, of which 830 are located in the intervention areas
*hence, we expected about 830 households (415 per information treatment arm) to particpate in the information experiment, but we have in total about 843 households who were part of the information experiment.
*meaning that we have a surplus of 13 households

count if (missing(women_25_60_number) & !missing(info_types) & types==1)
*we have in total 133 households that were provided with the information experiment while they do not have a women household memember aged between 25 and 60
*this should have been 0.

count if (!missing(women_25_60_number) & missing(tq1) & types==1 & info_types!=0)|(!missing(women_25_60_number) & missing(cq1) & types==1 & info_types!=1)
*we had 121 households that have a women household member between 25 and 60 in the treamtne areas, but are not part of the information experiment. 
*this should have been also zero.

count if (!missing(info_types) & types==2)
*we have 1 household in the non-intervention areas that is presented with the information experiment. 
*this should have been 0. 
gen eligible_exp=1 if types==1 
replace eligible_exp=0 if women_25_60_number==. & types==1 

gen info_treat_stat=0 if eligible_exp==1 & info_types==0
replace info_treat_stat=1 if eligible_exp==1 & info_types==1
replace info_treat_stat=-1 if eligible_exp==1 & info_types==.

/*
//====data for mapping

 keep info_treat_stat GPSLongitude GPSLatitude 
 
 export delimited "${data_path}/processed/Data_for_mapping.csv", replace


*/

//creating prior and posterior likehood of participation 
gen prior_like_part=tq1
replace prior_like_part=cq1 if prior_like_part==. 

gen post_like_part=tq2
replace post_like_part=cq2 if post_like_part==.

//generating the log of the prior and posterior likelihood of participation variable
gen post_like_part_log=log(post_like_part) 
gen prior_like_part_log=log(prior_like_part)

//generating individual perception variables composite perception variable
gen KDRDIP_heard_before=tf1
replace KDRDIP_heard_before=CQ3 if KDRDIP_heard_before==.

gen KDRDIP_heard_before_yes=KDRDIP_heard_before
replace KDRDIP_heard_before_yes=0 if KDRDIP_heard_before!=1

gen Per_take_oppo=tf2
replace Per_take_oppo=gp18gp17tf2 if Per_take_oppo==.

gen Per_ben_wom=tf3
replace Per_ben_wom=gp18gp17tf3 if Per_ben_wom==.

gen Per_ben_fam=tf4
replace Per_ben_fam=gp18gp17tf4 if Per_ben_fam==.

gen Per_ben_com=tf5
replace Per_ben_com=gp18gp17tf5 if Per_ben_com==.

gen Per_cont_comFaci=tf6
replace Per_cont_comFaci=gp18gp17tf6 if Per_cont_comFaci==.

global perception "Per_take_oppo Per_ben_wom Per_ben_fam Per_ben_com Per_cont_comFaci"

pca $perception if info_treat_stat==0|info_treat_stat==1
predict pc1
rename pc1 perception_index

global perception_perception_index "Per_take_oppo Per_ben_wom Per_ben_fam Per_ben_com Per_cont_comFaci perception_index"

egen perception_average=rowmean ($perception)

tab perception_average

//generating the log of the perception variables
foreach var in $perception {
    gen `var'_log=log(`var')
}

global perception_index_log "Per_take_oppo_log Per_ben_wom_log Per_ben_fam_log Per_ben_com_log Per_cont_comFaci_log"

global perception_log_perception_index "Per_take_oppo_log Per_ben_wom_log Per_ben_fam_log Per_ben_com_log Per_cont_comFaci_log perception_index"


//creating variables in whether women understood the different components of the script (the treatment)
gen Scrip_Under_encou_part=tf7
gen Scrip_Under_benef_you=tf8
gen Scrip_Under_benef_fam=tf9
gen Scrip_Under_benef_com=tf10
gen Scrip_Under_pho_comfac=tf11

global Scrip_understand "Scrip_Under_encou_part Scrip_Under_benef_you Scrip_Under_benef_fam Scrip_Under_benef_com Scrip_Under_pho_comfac"

foreach var of varlist Scrip_Under_encou_part-Scrip_Under_pho_comfac {
    gen `var'_dummy=1
	replace `var'_dummy=0 if `var'!=1
}

//generating an interaction between script understanding variables with prior likelihood of participation and whether heard about the project 
foreach var of varlist Scrip_Under_encou_part_dummy - Scrip_Under_pho_comfac_dummy {
    gen `var'PL=`var'*prior_like_part_log
	gen `var'PK=`var'*KDRDIP_heard_before_yes
}

//generating actual treatment status 
egen info_treat_stat_act_cou=rowtotal (Scrip_Under_encou_part_dummy Scrip_Under_benef_you_dummy Scrip_Under_benef_fam_dummy Scrip_Under_benef_com_dummy Scrip_Under_pho_comfac_dummy)

tab info_treat_stat_act_cou if info_treat_stat==1 | info_treat_stat==0

gen info_treat_stat_act_dum=1 if info_treat_stat_act_cou>0
replace info_treat_stat_act_dum=0 if info_treat_stat_act_cou==0

tab info_treat_stat if info_treat_stat==1 | info_treat_stat==0
tab info_treat_stat_act_dum if info_treat_stat==1 | info_treat_stat==0

gen ac_treatment_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_dum
gen ac_treatment_prior_like_part_log=prior_like_part_log*info_treat_stat_act_dum

gen ac_treat_cou_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_cou
gen ac_treat_cou_prior_like_part_log=prior_like_part_log*info_treat_stat_act_cou

gen info_treat_stat_act_cou_log =log(info_treat_stat_act_cou+1)

gen ac_treat_col_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_cou_log
gen ac_treat_col_prior_like_part_log=prior_like_part_log*info_treat_stat_act_cou_log

gen info_treat_stat_act_two_dum=1 if info_treat_stat_act_cou>1
replace info_treat_stat_act_two_dum=0 if info_treat_stat_act_cou<=1

gen info_treat_stat_act_three_dum=1 if info_treat_stat_act_cou>2
replace info_treat_stat_act_three_dum=0 if info_treat_stat_act_cou<=2

gen info_treat_stat_act_four_dum=1 if info_treat_stat_act_cou>3
replace info_treat_stat_act_four_dum=0 if info_treat_stat_act_cou<=3

gen info_treat_stat_act_five_dum=1 if info_treat_stat_act_cou>4
replace info_treat_stat_act_five_dum=0 if info_treat_stat_act_cou<=4

tab info_treat_stat if info_treat_stat==1 | info_treat_stat==0
tab info_treat_stat_act_dum if info_treat_stat==1 | info_treat_stat==0
tab info_treat_stat_act_two_dum if info_treat_stat==1 | info_treat_stat==0
tab info_treat_stat_act_three_dum if info_treat_stat==1 | info_treat_stat==0
tab info_treat_stat_act_four_dum if info_treat_stat==1 | info_treat_stat==0
tab info_treat_stat_act_five_dum if info_treat_stat==1 | info_treat_stat==0

gen ac_two_tre_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_two_dum
gen ac_two_tre_prior_like_part_log=prior_like_part_log*info_treat_stat_act_two_dum

gen ac_three_tre_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_three_dum
gen ac_three_tre_prior_like_part_log=prior_like_part_log*info_treat_stat_act_three_dum

gen ac_four_tre_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_four_dum
gen ac_four_tre_prior_like_part_log=prior_like_part_log*info_treat_stat_act_four_dum

gen ac_five_tre_heard_before=KDRDIP_heard_before_yes*info_treat_stat_act_five_dum
gen ac_five_tre_prior_like_part_log=prior_like_part_log*info_treat_stat_act_five_dum


//generating an interaction of treatment with prior information and prior likelihood of participate
gen treatment_heard_before=KDRDIP_heard_before_yes*info_treat_stat
gen treatment_prior_like_part_log=prior_like_part_log*info_treat_stat

//creating asset index using PCA
pca a819_1_a a819_2_a a819_3_a a819_4_a a819_5_a a819_6_a a819_7_a a819_8_a a819_9_a
predict pc1 
rename pc1 asset_index

//=========================================================================================
oneway a0 info_treat_stat, bonferroni //number of household members 
*different 

oneway a103_1 info_treat_stat, bonferroni //gender of household head 
*different 

oneway a104_1 info_treat_stat, bonferroni //age of household head  
*Not different

oneway a700 info_treat_stat, bonferroni //livestock owned
*Not different

oneway a700 info_treat_stat, bonferroni //livestock owned
*Not different

oneway child_0_6 info_treat_stat, bonferroni //Number of child (0-6)

oneway child_7_13 info_treat_stat, bonferroni //Number of child (7-13)

oneway adult_female_14_65  info_treat_stat, bonferroni 

oneway adult_male_14_65 info_treat_stat, bonferroni 

oneway adult_male_14_65 info_treat_stat, bonferroni 

oneway women_25_60_number info_treat_stat, bonferroni 

oneway  women_25_60_educ_mean  info_treat_stat, bonferroni 
oneway  women_25_60_age_mean  info_treat_stat, bonferroni 
oneway women_25_60_atte_scho_num  info_treat_stat, bonferroni 
oneway  women_25_60_housewif_num info_treat_stat, bonferroni 

tab a819_1_a info_treat_stat , chi  //radio

tab a819_2_a info_treat_stat, chi //TV

tab a819_3_a info_treat_stat, chi //Motorcycle

tab a819_4_a info_treat_stat, chi //Bicycle

tab a819_5_a info_treat_stat, chi //Mattress

tab a819_6_a info_treat_stat, chi //cellphone
 
tab a819_7_a info_treat_stat, chi //car/vehicle

tab a819_8_a info_treat_stat, chi //refrigerator

tab a819_9_a info_treat_stat, chi //refrigerator

/*
///=============================================================================================================
//list experiment===============================================================================================
//data gen 
gen treatment_list_exp=1 if tl3!=. 
replace treatment_list_exp=0 if tl3==.

gen list_count=tl3
replace list_count=cl1 if list_count==.

ttest list_count, by (treatment_list_exp)

*/

//labelling variables==================================================================================================
label variable info_treat_stat "Information treatment" 
label variable prior_like_part_log "Log (prior likelihood of participation)" 
label variable treatment_prior_like_part_log "Information treatment X log (prior likelihood of participation)"
label variable KDRDIP_heard_before_yes "Have heard about KDRDIP before " 
label variable treatment_heard_before "Information treatment X have heard KDRDIP before"
label variable ac_treatment_prior_like_part_log "Actual treatment status X log (prior likelihood of participation)"
label variable ac_treatment_heard_before "Actual treatment status X have heard KDRDIP before"


//livestock unit 
codebook a701_1 a701_2 a701_3 a701_4 a701_5 a701_6 a701_7 a701_8 a701_9 a701_10 a701_11 a701_13, compact  
codebook a701_1_1 a701_2_1 a701_3_1 a701_4_1 a701_5_1 a701_6_1 a701_7_1 a701_8_1 a701_9_1 a701_10_1, compact 

foreach var of varlist a701_1_1 a701_2_1 a701_3_1 a701_4_1 a701_5_1 a701_6_1 a701_7_1 a701_8_1 a701_9_1 a701_10_1 {
	replace `var'=0 if `var'==.
}
*****generating TLU
gen tlu=a701_1_1+a701_2_1+a701_3_1+0.405*(a701_4_1+a701_5_1+a701_6_1)+0.8*a701_7_1+1.2*a701_8_1+0.04*(a701_9_1+a701_10_1)

/*egen crop_prod = anycount(a119_1-a119_15), value (1) */

gen prim_occ_casual_head=1 if a119_1==6|a119_1==7
replace prim_occ_casual_head=0 if prim_occ_casual_head==.

gen prim_occ_agri_head=1 if a119_1==4|a119_1==5|a119_1==9
replace prim_occ_agri_head=0 if prim_occ_agri_head==.

gen prim_occ_hous_head=1 if a119_1==4|a119_1==3
replace prim_occ_hous_head=0 if prim_occ_hous_head==.

gen prim_occ_sala_head=1 if a119_1==10
replace prim_occ_sala_head=0 if prim_occ_sala_head==.

gen prim_bus_bus_head=1 if a119_1==8|a119_1==14
replace prim_bus_bus_head=0 if prim_bus_bus_head==.

//==generating head characterstics
gen head_gen_fem=1 if a103_1==2
replace head_gen_fem=0 if a103_1==1
gen head_educ_years=a109_1 
gen head_age_years=a104_1
gen head_married=1 if a106_1==1|a106_1==2
replace head_married=0 if head_married==.
sum head_gen_fem head_educ_years head_age_years head_married

//==log transformation
foreach var of varlist head_educ_years head_age_years child_0_6 child_7_13 adult_female_14_65 adult_male_14_65 elder_65 tlu {
	gen `var'_log=log(`var'+1)
}

/*
//==generating a child variable 
gen child_0_13=child_0_6+child_7_13, after (child_7_13)

//==distance to refugee camps
*ssc install geodist 

cross using "${data_path}/Refugee_camp_location.dta"
geodist GPSLatitude GPSLongitude Latitude Longitude, gen (distance_near_RC)
sort KEY distance_near_RC
by KEY: keep if _n==1

//==distance to facilities
gen pri_sch_in_vill_yes=1 if a205==1|a206==1|a205==98|a206==98
replace pri_sch_in_vill_yes=0 if pri_sch_in_vill_yes==.

gen sec_sch_in_vill_yes=1 if a207==1
replace sec_sch_in_vill_yes=0 if sec_sch_in_vill_yes==.

gen com_heal_fac_in_vill_yes=1 if a311_1==1
replace com_heal_fac_in_vill_yes=0 if com_heal_fac_in_vill_yes==.

gen dist_main_fire_source_min=a615_b
replace dist_main_fire_source_min=300 if dist_main_fire_source_min>300

//==group membership 
gen group_member_yes=1 if a727==1
replace group_member_yes=0 if group_member_yes==.

*/

///generating the variable women can leave hime without permission from the household
tab a1230
label list a1230
gen wom_leave_home_wo_hus_perm_yes= a1230
replace wom_leave_home_wo_hus_perm_yes=0 if a1230==2| a1230==98
